S3 Anypoint Connector Demo - Sending message to twitter
==============================================================

### INTRODUCTION

The present demo application provides a **complete workflow** to sequentially invoke some of S3's **standard operations**.
The Amazon S3 connector demo project consists of below flow:

### Prerequisites
In order to build run this demo project you'll need;

* Java 7 or higher
* Anypoint Studio 6.0.x or higher
* Anypoint Studio Mule Runtime 3.8.x EE or higher
* Mule Amazon S3 Connector v4.0.0 or higher.
* Mule Twitter Connector v4.0.0 or higher.
* Amazon S3 & Twitter OAuth Credentials.

## Import the project

* Go to **File > Import**
* Select **Anypoint Studio Project from External Location** (under the parent folder "Anypoint Studio")
* Provide the root path to the demo project folder.
* Select Mule Runtime (3.8.x EE).
* Click **Finish**.
* Set S3 credentials inside the file `src/main/app/mule-app.properties`. This may vary depending on the selected connection configuration. The current demo uses **S3 Access Key, Secret Key, bucket name and random bucket**:

    ```
    s3.accessKey=**************
    s3.secretKey=**************
    s3.bucketName=************
    s3.randomBucket=************
    ```

* Open the **Global Element Configuration** in S3 connector configuration
* Fill Access Key and Secret Key as `${s3.accessKey}`, `${s3.secretKey}` respectively. 
* Click the **Test Connection** button to ensure there is connectivity with the sandbox. A successful message should pop-up.

* Please read **Run the flows** section below to know how to get twitter credentials.
  Set twitter credentials inside the file `src/main/app/mule-app.properties`. This may vary depending on the selected connection configuration. The current demo uses **twitter Access Key, Secret Key, consumer key and consumer secret key**:

    ```
    twitter.access.key=**************
    twitter.access.secret=**************
    twitter.consumer.key=************
    twitter.consumer.secret=************
    ```

* Open the **Global Element Configuration** in twitter connector configuration
* Fill Access Key and Secret Key as `${twitter.access.key}`, `${twitter.access.secret}` respectively. Aslo fill consumer key and secret key as `${twitter.consumer.key}`,`${twitter.consumer.secret}`respectively. 
* Click the **Test Connection** button to ensure there is connectivity with the sandbox. A successful message should pop-up.
* Run the mule application.
* Open a browser and access the URL **http://localhost:8081/publish**. You should see the demo application deployed and see the result.

## About the flows
* **Amazon_S3_Twitter_Integration_Flow** - Provides an example on how to create an image link in Amazon S3 and update the status in twitter along with the image link. In this process it will show you how to create buckets, create object, copy object, create object uri and delete buckets using Amazon S3 Connector.
* **Create_Object_Sub_Flow** - This subflow fetch the logo from website and store in the S3 bucket.

### Run the flows

Before running the flow setup twitter account.
create the account in twitter. After that login the twitter account with credentials.
open the link **https://apps.twitter.com** in another tab and click **create new app** button on the top right side of the screen.

![Demo Create App-1](images/Demo-create-new-app-1.png)

enter the details and click button **create your twitter application** below of the screen.

![Demo Create App-2](images/Demo-create-new-app-2.png)

once application is created below screen will appear. Here copy the access tokens on the screen like `consumer key`, `consumer secret`, `access token` and `access token secret` and update them in `src/main/app/mule-app.properties`.
 
 ![Demo access tokens](images/Demo-app-access-tokens.png)
 
With Anypoint Studio up and running, run the application as mule application.Go to the browser and hit - **http://localhost:8081/publish**, The result would be a new tweet along with the url of the image.
![Demo twitter message](images/Demo-twitter-message-result.png)


SUMMARY
-------

Congratulations! You have imported the Mule Amazon S3 Demo project and used the Mule Amazon S3 Connector to post a image stored in Amazon S3 to twitter.

## See more

* For additional technical information on the S3 Connector, visit our [technical reference documentation](http://mulesoft.github.io/s3-connector/) or refer to the [S3 Documentation Site](https://docs.mulesoft.com/mule-user-guide/v/3.8/amazon-s3-connector).
* For more information on the S3 API, go to the [S3 API documentation page](https://aws.amazon.com/documentation/s3/).
